Design Notes
------------

DevDocs is a project documentation toolchain based on "gitbook". It's purpose to is to rapidly produce technical documentation
for a set of projects. The projects are often contributed by multiple (stakeholder) teams.

DevDocs are produced on behalf of a "client" - in which case, the client may (will) supply multiple "project" folders.

Each "project" folder is a standard gitbook project - that is consitently rendered for a given client.

A "client" folder will usually contain a "home" or "default" project that is used to render the home page, menus, etc.

Ideally, each project can be regenerated individually [Q: how does 'home' know what has changed]

The "home" project should allow navigating and searching all projects.

Some pages (i.e. home page) will be supplied in HTML not Markdown. Typically, from a business rather than a technical author.

Gitbook vs DevDocs
------------------

DevDocs differs from gitbook in a few notable ways:

    1) Multiple 'gitbook' projects must be combined into a single "client" site
    2) The theme must consolidate multiple projects and provide a unified brand / experience (esp. headers, main menu, footers, etc)
    3) Render to 3rd party documentation tools - i.e. Confluence
    4) Private plugins will be developers - for example an API-based "Try It Now" and "Developer Registration"
    5) Each project should be output to a sub-folder that includes it's "semver" major version number
    6) A selection of plugins will be pre-configured.
    7) A single "master" configuration file (see devdocs.yaml) should be used. It should configure each sub-project.
    8) A unified "sitemap", "table of contents" and main menu will be provided
    9) Search must work across a single "project" or "whole site" based on a simple selection

Publishing Requirements
-----------------------

A project folder will contain various assets that will be rendered / published, for example:

    1) Markdown Files
    2) Diagrams (PNG, JPG, etc) + PDFs
    3) Swagger / OpenAPI docs
    4) Sequence Diagrams (evaluate available plugins)
    5) Flow Charts (see #5)
    6) Main Menu (top bar?) - multiple projects + links to other parts of site)
    7) Per-project menu (side bar?) - based on SUMMARY.MD
    8) "home" project describes home page + main menu + generic / static content
    9) A single output is produced that comprises a fully integrated "client" site.


API - Try It Now
----------------

The plugin should integrate with gitbook initially but support embedding into other web pages.

The plugin reads a Swagger definition to generate a web form.

The web form allows a user to issue an HTTP GET/POST/PUT/DELETE etc request.

The web form should support custom headers, query params, and a simple body (JSON).

It should render a formatted table for JSON (CSV, etc), plus syntax highlighting (for any textual output)

It should render an icon and links for non-text (binary) downloadable content.

Each Swagger file may contain multiple resources (paths/routes) - each should be selectable.

The plugin should render the selected "resource" when started from a part of the page that describes that resource (contextual).


Generate Confluence Pages
--------------------------

Atlassian's Confluence is popular documentation tool.

The "DevDocs" toolchain should be capable of rendering all or part of the client or project folders to a Confluence Space.

Further investigation is required to determine the navigation and structure of the generated pages.


